@@ -1,3 +1,3 @@
-fn sayHello() {
+pub fn sayHello() {
   println!("Hello, world!");
 }
\ No newline at end of file
